import { Component, OnInit } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import { Eventroom } from '../../_models/eventroom';
import { EventroomService } from '../../_services/eventroom.service';
import {Event} from '../../_models/event';
import {Room} from '../../_models/room';
import {EventService} from '../../_services/event.service';
import {RoomService} from '../../_services/room.service';

@Component({
  selector: 'app-eventroom-update',
  templateUrl: './eventroom-update.component.html',
  styleUrls: ['./eventroom-update.component.css']
})
export class EventroomUpdateComponent implements OnInit {

  id: number;
  eventroom: Eventroom;

  events: Event[] = [];
  rooms: Room[] = [];
  eventSelect;
  roomSelect;

  eventSelected: number;
  roomSelected: number;

  event: Event = new Event();
  room: Room = new Room();

  constructor(private route: ActivatedRoute, private router: Router,
              private eventroomService: EventroomService, private eventService: EventService,
              private roomService: RoomService) { }

  ngOnInit() {
    this.eventService.getEventsList().subscribe(events => this.events = events);
    this.roomService.getRoomsList().subscribe(rooms => this.rooms = rooms);

    this.eventroom = new Eventroom();

    this.id = this.route.snapshot.params.id;

    this.eventroomService.getEventroom(this.id)
      .subscribe(data => {
        console.log(data);
        this.eventroom = data;
        this.eventSelected = this.eventroom.event.id;
        this.roomSelected = this.eventroom.room.id;
      }, error => console.log(error));

  }

  updateEventroom() {
    this.eventroom.updatedBy = 'frontend';
    this.eventroom.createdBy = 'frontend';

    console.log('eventSelect: ' + this.eventSelect)
    console.log('roomSelect: ' + this.roomSelect);

    if (this.eventSelect === undefined) {
      this.eventSelect = this.eventSelected;
    }
    if (this.roomSelect === undefined) {
      this.roomSelect = this.roomSelected;
    }

    this.eventroom.event = this.event;
    this.eventroom.room = this.room;

    this.eventService.getEvent(this.eventSelect)
      .subscribe(data => {
        console.log(data);
        this.event = data;

      }, error => console.log(error));

    this.roomService.getRoom(this.roomSelect)
      .subscribe(data => {
        console.log(data);
        this.room = data;

      }, error => console.log(error));

    this.eventroom.event = this.event;
    this.eventroom.room = this.room;

    this.eventroomService.updateEventroom(this.id, this.eventroom)
      .subscribe(data => console.log(data), error => console.log(error));
    this.eventroom = new Eventroom();
    this.gotoList();
  }

  gotoList() {
    this.router.navigate(['/eventroom/eventrooms']);
  }

  onSubmit() {
    this.updateEventroom();
  }

}
